.. chunky documentation master file

Welcome to Chunky's documentation!
=================================

Chunky provides modular chunking primitives tailored for heterogeneous scientific repositories.
It is designed to serve both the Nancy Brain knowledge-base pipeline and any external RAG
pipelines that need deterministic, metadata-rich chunks.

.. toctree::
   :maxdepth: 2
   :caption: Contents

   overview
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
